summaryrefslogtreecommitdiff
path: root/src/mongo/db/storage/wiredtiger/wiredtiger_kv_engine.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/storage/wiredtiger/wiredtiger_kv_engine.h')
-rw-r--r--src/mongo/db/storage/wiredtiger/wiredtiger_kv_engine.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/storage/wiredtiger/wiredtiger_kv_engine.h b/src/mongo/db/storage/wiredtiger/wiredtiger_kv_engine.h
index eadcbc6a188..80dc2c370c7 100644
--- a/src/mongo/db/storage/wiredtiger/wiredtiger_kv_engine.h
+++ b/src/mongo/db/storage/wiredtiger/wiredtiger_kv_engine.h
@@ -304,7 +304,7 @@ public:
* be started and stopped multiple times as tests create and destroy the oplog record store.
*/
void startOplogManager(OperationContext* opCtx, WiredTigerRecordStore* oplogRecordStore);
- void haltOplogManager();
+ void haltOplogManager(WiredTigerRecordStore* oplogRecordStore);
/*
* Always returns a non-nil pointer. However, the WiredTigerOplogManager may not have been
@@ -430,9 +430,9 @@ private:
std::unique_ptr<WiredTigerSessionCache> _sessionCache;
ClockSource* const _clockSource;
// Mutex to protect use of _oplogManagerCount by this instance of KV engine.
mutable Mutex _oplogManagerMutex = MONGO_MAKE_LATCH("::_oplogManagerMutex");
- std::size_t _oplogManagerCount = 0;
+ const WiredTigerRecordStore* _oplogRecordStore = nullptr;
std::unique_ptr<WiredTigerOplogManager> _oplogManager;
std::string _canonicalName;
@@ -430,9 +430,9 @@ private:
std::unique_ptr<WiredTigerSessionCache> _sessionCache;
ClockSource* const _clockSource;
- // Mutex to protect use of _oplogManagerCount by this instance of KV engine.
+ // Mutex to protect use of _oplogRecordStore by this instance of KV engine.
mutable Mutex _oplogManagerMutex = MONGO_MAKE_LATCH("::_oplogManagerMutex");